quickLR: LR calculations for paternity and sibship

View source: R/quickLR.R

quickLRR Documentation

LR calculations for paternity and sibship

Description

A thin wrapper around kinshipLR() for the common scenario of testing a pair of individuals for paternity or sibship against being unrelated.

Usage

quickLR(x, ids = typedMembers(x), test = c("pat", "sib", "half", "cous"))

Arguments

x

A ped object or a list of such.

ids

A vector of two typed members of x. If not given, the typed members of x are selected by default, but note that this gives an error if the number of such individuals is not 2.

test

The hypotheses to be tested against unrelatedness. Allowed values are "pat" (= paternity), "sib" (= full siblings), "half" (= half siblings) and "cous" (= first cousins). By default, all are included.

Value

A (slightly simplified) LRresult object, as described in kinshipLR().

Examples

# Simulate 100 markers for half siblings
x = halfSibPed() |> markerSim(N = 100, ids = 4:5, alleles = 1:3, seed = 1)

# Test for paternity, full sibs, half sibs, 1st cousins
quickLR(x)


forrel documentation built on June 28, 2026, 5:07 p.m.