randomPersonEP: Random person exclusion power

View source: R/randomPersonEP.R

randomPersonEPR Documentation

Random person exclusion power

Description

This is a special case of exclusionPower(), computing the power to exclude a random person as a given pedigree member. More specifically, the function computes the probability of observing, in an individual unrelated to the family individual, a genotype incompatible with the typed family members.

Usage

randomPersonEP(x, id, markers = NULL, disableMutations = NA, verbose = TRUE)

Arguments

x

A ped object with attached markers.

id

The ID label of a single pedigree member.

markers

Names or indices of attached markers to include. By default all markers.

disableMutations

This parameter determines how mutation models are treated. Possible values are as follows:

  • NA (the default): Mutations are disabled only for those markers whose known genotypes are consistent with the pedigree. This is determined by temporarily removing all mutation models and checking which markers have nonzero likelihood.

  • TRUE: Mutations are disabled for all markers. This will result in an error if any markers are inconsistent.

  • FALSE: No action is done to disable mutations.

  • A vector containing the names or indices of those markers for which mutations should be disabled.

verbose

A logical.

Value

The EPresult object returned by exclusionPower().

Examples


# Four siblings:
x = nuclearPed(4)

# First 3 sibs typed with 4 triallelic markers
x = markerSim(x, N = 4, ids = 3:5, alleles = 1:3, seed = 577, verbose = FALSE)

# Probability that a random man is excluded as the fourth sibling
randomPersonEP(x, id = 6)


forrel documentation built on Oct. 6, 2026, 5:06 p.m.