a positive integer: the number of markers to be simulated
alleles
a vector containing the allele names. If missing, the alleles
are taken to be seq_along(afreq).
afreq
a vector of length 2 containing the population frequencies for
the alleles. If missing, the alleles are assumed equifrequent.
ids
a vector containing ID labels of those pedigree members whose
genotypes should be simulated.
Xchrom
a logical: X linked markers or not?
mutmod
a pedmut::mutationModel() object, i.e., list of mutation matrices named
'female' and 'male'.
seed
NULL, or a numeric seed for the random number generator.
verbose
a logical.
Value
a ped object equal to x in all respects except its MARKERS
entry, which consists of the N simulated markers.
Details
This simulation is done by distributing alleles randomly to all founders,
followed by unconditional gene dropping down throughout the pedigree (i.e.
for each non-founder a random allele is selected from each of the parents).
Finally the genotypes of any individuals not included in ids are removed.
# NOT RUN {library(pedtools)
x = nuclearPed(1)
simpleSim(x, N = 3, afreq = c(0.5, 0.5))
y = cousinPed(1, child = TRUE)
simpleSim(y, N = 3, alleles = LETTERS[1:10])
# }